==> kubernetes-model-core-5.1.1-sources.jar: io/fabric8/kubernetes/api/model/ConfigMapFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ConfigMapFluent<A extends ConfigMapFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToBinaryData(String key,String value);
    public A addToBinaryData(Map<String,String> map);
    public A removeFromBinaryData(String key);
    public A removeFromBinaryData(Map<String,String> map);
    public Map<String,String> getBinaryData();
    public A withBinaryData(Map<String,String> binaryData);
    public Boolean hasBinaryData();
    public A addToData(String key,String value);
    public A addToData(Map<String,String> map);
    public A removeFromData(String key);
    public A removeFromData(Map<String,String> map);
    public Map<String,String> getData();
    public A withData(Map<String,String> data);
    public Boolean hasData();
    public Boolean isImmutable();
    public A withImmutable(Boolean immutable);
    public Boolean hasImmutable();
    public A withNewImmutable(String arg1);
    public A withNewImmutable(boolean arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public ConfigMapFluent.MetadataNested<A> withNewMetadata();
    public ConfigMapFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ConfigMapFluent.MetadataNested<A> editMetadata();
    public ConfigMapFluent.MetadataNested<A> editOrNewMetadata();
    public ConfigMapFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<ConfigMapFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


}

==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/ConfigMapFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ConfigMapFluent<A extends ConfigMapFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToBinaryData(String key,String value);
    public A addToBinaryData(Map<String,String> map);
    public A removeFromBinaryData(String key);
    public A removeFromBinaryData(Map<String,String> map);
    public Map<String,String> getBinaryData();
    public <K extends Object,V extends Object>A withBinaryData(Map<String,String> binaryData);
    public Boolean hasBinaryData();
    public A addToData(String key,String value);
    public A addToData(Map<String,String> map);
    public A removeFromData(String key);
    public A removeFromData(Map<String,String> map);
    public Map<String,String> getData();
    public <K extends Object,V extends Object>A withData(Map<String,String> data);
    public Boolean hasData();
    public Boolean getImmutable();
    public A withImmutable(Boolean immutable);
    public Boolean hasImmutable();
    public A withNewImmutable(String arg1);
    public A withNewImmutable(boolean arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public ConfigMapFluent.MetadataNested<A> withNewMetadata();
    public ConfigMapFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ConfigMapFluent.MetadataNested<A> editMetadata();
    public ConfigMapFluent.MetadataNested<A> editOrNewMetadata();
    public ConfigMapFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<ConfigMapFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


}
